#!/bin/bash

usage()
{
	echo -e "Usage: $0 [-h] <custom_liveburner.ipk>
\t-h: this usage
\tcustom_liveburner.ipk: custom liveburner to extract elements from"
}

if [ $# -lt 1 ]
then
	usage
	exit 1
fi

while getopts "h" opt; do
	case "$opt" in
	h)
		usage
		exit 1
		;;
	*)
		usage
		exit 1
		;;
	esac
done

command -v tree >/dev/null 2>&1 || { echo >&2 "Please install tree command (apt install tree).  Aborting."; exit 1; }

UPDATELIVEBURNERLOG=/tmp/updateliveburner.log
LIVEBURNER_PATH=`realpath -L "$1"`
LIVEBURNER_FILENAME=`basename "${LIVEBURNER_PATH}"`
LIVEBURNER_PATH=`dirname "${LIVEBURNER_PATH}"`
LIVEBURNER_ELEMS_PATH="${LIVEBURNER_PATH}/${LIVEBURNER_FILENAME%.*}"
WORKING_DIR=`pwd`

. functions

#########################
# MAIN
#########################

ipk_extract "$1" "${WORKSPACE}" >> ${UPDATELIVEBURNERLOG}

echo -e "== Package content ==\n"
tree "${WORKSPACE}/ipk/"

echo -e "\n== Package CONTROL ==\n"
cat "${WORKSPACE}/ipk/control/control"

itb_extract "${ITB_WORKSPACE}/linux.itb" "${ITB_WORKSPACE}" >> ${UPDATELIVEBURNERLOG}
initrd_extract "${INITRD_DIR}/ramdisk" "${INITRD_DIR}" >> ${UPDATELIVEBURNERLOG}

echo -e "\n== Burner content ==\n"
tree "${ITB_WORKSPACE}/burner/"

rm -rf "${WORKSPACE}"
