#!/bin/bash

OPTIND=1

# Versions
SCRIPT_VERSION="v5.5.4-0-g7206c44"

# Comments on the final custom liveburner
IPK_COMMENT=""

usage()
{
	echo -e "Usage: $0 [-v] [-m <comment>][-h] <liveburner.ipk> <file 1>...<file n>
\t-v: Show versions
\t-m: Add comment in CONTROL file
\t-h: this usage
\tliveburner.ipk: liveburner file to be updated with ipk
\tfile X: list of ipk and/or scripts to be added to the liveburner"
}

get_version()
{
	echo "Script version: ${SCRIPT_VERSION}"
}

if [ $# -lt 1 ]
then
	usage
	exit 1
fi

while getopts "hvm:" opt; do
	case "$opt" in
	h)
		usage
		exit 1
		;;
	v)
		get_version
		exit 1
		;;
	m)
		IPK_COMMENT="${OPTARG}"
		;;
	*)
		usage
		exit 1
		;;
	esac
done

[ ! -z "${IPK_COMMENT}" ] && shift 2

UPDATELIVEBURNERLOG=/tmp/updateliveburner.log
exec 3>&1 4>&2 > ${UPDATELIVEBURNERLOG}

LIVEBURNER_PATH=`realpath -L "$1"`
LIVEBURNER_FILENAME=`basename "${LIVEBURNER_PATH}"`
LIVEBURNER_PATH=`dirname "${LIVEBURNER_PATH}"`
WORKING_DIR=`pwd`

. functions

#########################
# MAIN
#########################

detect_liveburner_machine
ipk_extract "$1" "${WORKSPACE}"

cd "${WORKING_DIR}"
[ ! -z "${IPK_COMMENT}" ] && echo "   Burner information: ${IPK_COMMENT}" >> "${WORKSPACE}/ipk/control/control"
echo "   Files added:" >> "${WORKSPACE}/ipk/control/control"
shift
while [ $# != 0 ]
do
	if [ -f "$1" ]
	then
		FILENAME=$(basename -- "$1")

		# preinst script is specific and must be installed in liveburner
		if [ "${FILENAME}" = "preinst" ]
		then
			mkdir -p "${IPK_WORKSPACE}/control/"
			cp "$1" "${IPK_WORKSPACE}/control/"
			chmod 777 "${IPK_WORKSPACE}/control/${FILENAME}"
		elif [ "${FILENAME}" = "postinst" ]
		then
			mkdir -p "${ITB_WORKSPACE}/hook"
			cp "$1" "${ITB_WORKSPACE}/hook/"
			chmod 777 "${ITB_WORKSPACE}/hook/${FILENAME}"
		else
			mkdir -p "${ITB_WORKSPACE}/burner"
			cp "$1" "${ITB_WORKSPACE}/burner/"
			chmod 777 "${ITB_WORKSPACE}/burner/${FILENAME}"
		fi

		echo "      ${FILENAME}" >> "${WORKSPACE}/ipk/control/control"
		shift
	else
		echo "Error: file $1 not found"
		rm -rf ${WORKSPACE}
		exit 1
	fi
done
echo "   Build from update_liveburner ${SCRIPT_VERSION}" >> "${WORKSPACE}/ipk/control/control"

# Add files to be added to roofs
if [ -d ${WORKING_DIR}/files/rootfs ]; then
		mkdir -p "${ITB_WORKSPACE}/burner"
		tar --owner=root --group=root -czf "${ITB_WORKSPACE}/burner/rootfs.tar.gz" -C "${WORKING_DIR}/files/rootfs" .
fi

# Update control -> Depends field to be applied only on keros (= 4.3.3),
KEROS_VERSION="4.3.3-0-g993efce1"
sed -i "s/^Depends:.*/Depends: keros (=${KEROS_VERSION})/" ${IPK_WORKSPACE}/control/control

ipk_build "${WORKSPACE}" "${LIVEBURNER_PATH}/custom-${LIVEBURNER_FILENAME}"

rm -rf "${WORKSPACE}"

exec echo "Liveburner custom-${LIVEBURNER_FILENAME} created" 1>&3
